==> delete_orphaned_non_reusable_blocks-1.0.0.tar.gz: delete_orphaned_non_reusable_blocks/src/Form/DeleteOrphanedNonReusableBlocksConfirmForm.php <==
<?php

namespace Drupal\delete_orphaned_non_reusable_blocks\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Defines a confirmation form to confirm deletion of orphaned non reusable blocks.
 */
class DeleteOrphanedNonReusableBlocksConfirmForm extends ConfirmFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'delete_orphaned_non_reusable_blocks_confirm_form';
  }

  /**
   * Number of orphans that will be deleted.
   *
   * @var int
   */
  protected $orphanCount;

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, string $orphanCount = NULL) {
 
    $this->orphanCount = $orphanCount;

    $form['info'] = [
      '#markup' => '<p>' . $this->t('Are you sure you want to delete %count orphaned non reusable block content items?', ['%count' => $this->orphanCount]) . '</p>',
    ];

    return parent::buildForm($form, $form_state);
   }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $this->deleteOrphans();

    \Drupal::messenger()->addMessage('All orphaned non reusable block content entities have been deleted');

    $form_state->setRedirect('delete_orphaned_non_reusable_blocks');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('delete_orphaned_non_reusable_blocks');
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Confirm deletion');
  }

  private function deleteOrphans() {

    // Get the inline block usage service
    $srvUsage = \Drupal::service('inline_block.usage');

    // Get all block content ids
    $ids = \Drupal::entityQuery('block_content')->execute();

    // Loop all fids and load files by fid
    foreach ($ids as $id) {

      $block = \Drupal\block_content\Entity\BlockContent::load($id);

      // If this is a non reusable block then its been added in layout builder
      if (!$block->isReusable()) {

        // Get the usage for the block
        $usage = $srvUsage->getUsage(intval($id));

        // Check if block not used and if not delete it
        if (empty($usage)) {

          \Drupal::logger('delete_orphaned_non_reusable_blocks')
            ->notice('Deleted orphaned non reusable block @blockid', [ 
              '@blockid' => $id
            ]);

          $block->delete();
        }
      }
    }
  }
}

==> delete_orphaned_non_reusable_blocks-1.0.1.tar.gz: delete_orphaned_non_reusable_blocks/src/Form/DeleteOrphanedNonReusableBlocksConfirmForm.php <==
<?php

namespace Drupal\delete_orphaned_non_reusable_blocks\Form;

use Drupal\block_content\Entity\BlockContent;
use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Confirmation form to confirm deletion of orphaned non-reusable blocks.
 */
class DeleteOrphanedNonReusableBlocksConfirmForm extends ConfirmFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'delete_orphaned_non_reusable_blocks_confirm_form';
  }

  /**
   * Number of orphans that will be deleted.
   *
   * @var int
   */
  protected $orphanCount;

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, string $orphanCount = NULL) {

    $this->orphanCount = $orphanCount;

    $form['info'] = [
      '#markup' => '<p>' . $this->t('Are you sure you want to delete %count orphaned non reusable block content items?', ['%count' => $this->orphanCount]) . '</p>',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $this->deleteOrphans();

    \Drupal::messenger()->addMessage('All orphaned non reusable block content entities have been deleted');

    $form_state->setRedirect('delete_orphaned_non_reusable_blocks');
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('delete_orphaned_non_reusable_blocks');
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Confirm deletion');
  }

  /**
   * {@inheritdoc}
   */
  private function deleteOrphans() {

    // Get the inline block usage service.
    $srvUsage = \Drupal::service('inline_block.usage');

    // Get all block content ids.
    $ids = \Drupal::entityQuery('block_content')->execute();

    // Loop all fids and load files by fid.
    foreach ($ids as $id) {

      $block = BlockContent::load($id);

      // If this is a non-reusable block then it has been added in layout
      // builder.
      if (!$block->isReusable()) {

        // Get the usage for the block.
        $usage = $srvUsage->getUsage(intval($id));

        // Check if block not used and if not delete it.
        if (empty($usage)) {

          \Drupal::logger('delete_orphaned_non_reusable_blocks')
            ->notice('Deleted orphaned non reusable block @blockid', [
              '@blockid' => $id,
            ]);

          $block->delete();
        }
      }
    }
  }

}
